// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_qpwgraph.cpp"
#include "EWIEGA46WW/moc_qpwgraph_alsamidi.cpp"
#include "EWIEGA46WW/moc_qpwgraph_canvas.cpp"
#include "EWIEGA46WW/moc_qpwgraph_main.cpp"
#include "EWIEGA46WW/moc_qpwgraph_options.cpp"
#include "EWIEGA46WW/moc_qpwgraph_patchman.cpp"
#include "EWIEGA46WW/moc_qpwgraph_pipewire.cpp"
#include "EWIEGA46WW/moc_qpwgraph_sect.cpp"
#include "EWIEGA46WW/moc_qpwgraph_systray.cpp"
#include "EWIEGA46WW/moc_qpwgraph_thumb.cpp"
