/****************************************************************************
** Meta object code from reading C++ file 'qpwgraph_main.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../qpwgraph-v1.0.3/src/qpwgraph_main.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qpwgraph_main.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13qpwgraph_mainE_t {};
} // unnamed namespace

template <> constexpr inline auto qpwgraph_main::qt_create_metaobjectdata<qt_meta_tag_ZN13qpwgraph_mainE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qpwgraph_main",
        "added",
        "",
        "qpwgraph_node*",
        "node",
        "updated",
        "removed",
        "connected",
        "qpwgraph_port*",
        "port1",
        "port2",
        "disconnected",
        "qpwgraph_connect*",
        "connect",
        "renamed",
        "qpwgraph_item*",
        "item",
        "name",
        "changed",
        "pipewire_changed",
        "alsamidi_changed",
        "refresh",
        "stabilize",
        "orientationChanged",
        "Qt::Orientation",
        "orientation",
        "graphOptions",
        "patchbayNew",
        "patchbayOpen",
        "patchbayOpenRecent",
        "patchbaySave",
        "patchbaySaveAs",
        "patchbayActivated",
        "on",
        "patchbayExclusive",
        "patchbayEdit",
        "patchbayPin",
        "patchbayUnpin",
        "patchbayAutoPin",
        "patchbayAutoDisconnect",
        "patchbayManage",
        "viewMenubar",
        "viewGraphToolbar",
        "viewPatchbayToolbar",
        "viewStatusbar",
        "viewThumbviewAction",
        "viewThumbview",
        "thumbview",
        "viewTextBesideIcons",
        "viewCenter",
        "viewRefresh",
        "viewZoomRange",
        "viewSortTypeAction",
        "viewSortOrderAction",
        "viewColorsAction",
        "viewColorsReset",
        "viewRepelOverlappingNodes",
        "viewConnectThroughNodes",
        "helpAbout",
        "helpAboutQt",
        "thumbviewContextMenu",
        "QPoint",
        "pos",
        "zoomValueChanged",
        "zoom_value",
        "patchbayNameChanged",
        "index",
        "updatePatchbayMenu",
        "closeQuit",
        "commitData",
        "QSessionManager&",
        "sm"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'added'
        QtMocHelpers::SlotData<void(qpwgraph_node *)>(1, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'updated'
        QtMocHelpers::SlotData<void(qpwgraph_node *)>(5, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'removed'
        QtMocHelpers::SlotData<void(qpwgraph_node *)>(6, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'connected'
        QtMocHelpers::SlotData<void(qpwgraph_port *, qpwgraph_port *)>(7, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 8, 10 },
        }}),
        // Slot 'disconnected'
        QtMocHelpers::SlotData<void(qpwgraph_port *, qpwgraph_port *)>(11, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 8, 10 },
        }}),
        // Slot 'connected'
        QtMocHelpers::SlotData<void(qpwgraph_connect *)>(7, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'renamed'
        QtMocHelpers::SlotData<void(qpwgraph_item *, const QString &)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'changed'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'pipewire_changed'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'alsamidi_changed'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'stabilize'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'orientationChanged'
        QtMocHelpers::SlotData<void(Qt::Orientation)>(23, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'graphOptions'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'patchbayNew'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'patchbayOpen'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'patchbayOpenRecent'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'patchbaySave'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'patchbaySaveAs'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'patchbayActivated'
        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'patchbayExclusive'
        QtMocHelpers::SlotData<void(bool)>(34, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'patchbayEdit'
        QtMocHelpers::SlotData<void(bool)>(35, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'patchbayPin'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'patchbayUnpin'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'patchbayAutoPin'
        QtMocHelpers::SlotData<void(bool)>(38, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'patchbayAutoDisconnect'
        QtMocHelpers::SlotData<void(bool)>(39, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'patchbayManage'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'viewMenubar'
        QtMocHelpers::SlotData<void(bool)>(41, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'viewGraphToolbar'
        QtMocHelpers::SlotData<void(bool)>(42, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'viewPatchbayToolbar'
        QtMocHelpers::SlotData<void(bool)>(43, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'viewStatusbar'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'viewThumbviewAction'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'viewThumbview'
        QtMocHelpers::SlotData<void(int)>(46, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 47 },
        }}),
        // Slot 'viewTextBesideIcons'
        QtMocHelpers::SlotData<void(bool)>(48, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'viewCenter'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'viewRefresh'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'viewZoomRange'
        QtMocHelpers::SlotData<void(bool)>(51, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'viewSortTypeAction'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'viewSortOrderAction'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'viewColorsAction'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'viewColorsReset'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'viewRepelOverlappingNodes'
        QtMocHelpers::SlotData<void(bool)>(56, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'viewConnectThroughNodes'
        QtMocHelpers::SlotData<void(bool)>(57, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'helpAbout'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'helpAboutQt'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'thumbviewContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(60, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 61, 62 },
        }}),
        // Slot 'zoomValueChanged'
        QtMocHelpers::SlotData<void(int)>(63, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 64 },
        }}),
        // Slot 'patchbayNameChanged'
        QtMocHelpers::SlotData<void(int)>(65, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 66 },
        }}),
        // Slot 'updatePatchbayMenu'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'closeQuit'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'commitData'
        QtMocHelpers::SlotData<void(QSessionManager &)>(69, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 70, 71 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<qpwgraph_main, qt_meta_tag_ZN13qpwgraph_mainE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qpwgraph_main::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13qpwgraph_mainE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13qpwgraph_mainE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13qpwgraph_mainE_t>.metaTypes,
    nullptr
} };

void qpwgraph_main::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<qpwgraph_main *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->added((*reinterpret_cast<std::add_pointer_t<qpwgraph_node*>>(_a[1]))); break;
        case 1: _t->updated((*reinterpret_cast<std::add_pointer_t<qpwgraph_node*>>(_a[1]))); break;
        case 2: _t->removed((*reinterpret_cast<std::add_pointer_t<qpwgraph_node*>>(_a[1]))); break;
        case 3: _t->connected((*reinterpret_cast<std::add_pointer_t<qpwgraph_port*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qpwgraph_port*>>(_a[2]))); break;
        case 4: _t->disconnected((*reinterpret_cast<std::add_pointer_t<qpwgraph_port*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qpwgraph_port*>>(_a[2]))); break;
        case 5: _t->connected((*reinterpret_cast<std::add_pointer_t<qpwgraph_connect*>>(_a[1]))); break;
        case 6: _t->renamed((*reinterpret_cast<std::add_pointer_t<qpwgraph_item*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->changed(); break;
        case 8: _t->pipewire_changed(); break;
        case 9: _t->alsamidi_changed(); break;
        case 10: _t->refresh(); break;
        case 11: _t->stabilize(); break;
        case 12: _t->orientationChanged((*reinterpret_cast<std::add_pointer_t<Qt::Orientation>>(_a[1]))); break;
        case 13: _t->graphOptions(); break;
        case 14: _t->patchbayNew(); break;
        case 15: _t->patchbayOpen(); break;
        case 16: _t->patchbayOpenRecent(); break;
        case 17: _t->patchbaySave(); break;
        case 18: _t->patchbaySaveAs(); break;
        case 19: _t->patchbayActivated((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->patchbayExclusive((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->patchbayEdit((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->patchbayPin(); break;
        case 23: _t->patchbayUnpin(); break;
        case 24: _t->patchbayAutoPin((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->patchbayAutoDisconnect((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->patchbayManage(); break;
        case 27: _t->viewMenubar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->viewGraphToolbar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->viewPatchbayToolbar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->viewStatusbar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->viewThumbviewAction(); break;
        case 32: _t->viewThumbview((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->viewTextBesideIcons((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->viewCenter(); break;
        case 35: _t->viewRefresh(); break;
        case 36: _t->viewZoomRange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->viewSortTypeAction(); break;
        case 38: _t->viewSortOrderAction(); break;
        case 39: _t->viewColorsAction(); break;
        case 40: _t->viewColorsReset(); break;
        case 41: _t->viewRepelOverlappingNodes((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 42: _t->viewConnectThroughNodes((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 43: _t->helpAbout(); break;
        case 44: _t->helpAboutQt(); break;
        case 45: _t->thumbviewContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 46: _t->zoomValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 47: _t->patchbayNameChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 48: _t->updatePatchbayMenu(); break;
        case 49: _t->closeQuit(); break;
        case 50: _t->commitData((*reinterpret_cast<std::add_pointer_t<QSessionManager&>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *qpwgraph_main::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qpwgraph_main::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13qpwgraph_mainE_t>.strings))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int qpwgraph_main::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 51)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 51;
    }
    return _id;
}
QT_WARNING_POP
