/*
qpwgraph - A PipeWire Graph Qt GUI Interface

   Copyright (C) 2021-2025, rncbc aka Rui Nuno Capela. All rights reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 
*/

/********************************************************************************
** Form generated from reading UI file 'qpwgraph_options.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QPWGRAPH_OPTIONS_H
#define UI_QPWGRAPH_OPTIONS_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_qpwgraph_options
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *OptionsTabWidget;
    QWidget *GeneralTabPage;
    QGridLayout *gridLayout;
    QCheckBox *SystemTrayEnabledCheckBox;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;
    QCheckBox *SystemTrayQueryCloseCheckBox;
    QCheckBox *SystemTrayStartMinimizedCheckBox;
    QSpacerItem *spacerItem2;
    QCheckBox *PatchbayQueryQuitCheckBox;
    QSpacerItem *spacerItem3;
    QSpacerItem *spacerItem4;
    QCheckBox *AlsaMidiEnabledCheckBox;
    QWidget *FilterNodesTabPage;
    QGridLayout *gridLayout1;
    QCheckBox *FilterNodesEnabledCheckBox;
    QComboBox *FilterNodesNameComboBox;
    QToolButton *FilterNodesAddToolButton;
    QListWidget *FilterNodesListWidget;
    QToolButton *FilterNodesRemoveToolButton;
    QSpacerItem *spacerItem5;
    QToolButton *FilterNodesClearToolButton;
    QSpacerItem *spacerItem6;
    QWidget *MergerNodesTabPage;
    QGridLayout *gridLayout2;
    QCheckBox *MergerNodesEnabledCheckBox;
    QComboBox *MergerNodesNameComboBox;
    QToolButton *MergerNodesAddToolButton;
    QListWidget *MergerNodesListWidget;
    QToolButton *MergerNodesRemoveToolButton;
    QSpacerItem *spacerItem7;
    QToolButton *MergerNodesClearToolButton;
    QSpacerItem *spacerItem8;
    QDialogButtonBox *DialogButtonBox;

    void setupUi(QDialog *qpwgraph_options)
    {
        if (qpwgraph_options->objectName().isEmpty())
            qpwgraph_options->setObjectName("qpwgraph_options");
        qpwgraph_options->resize(240, 120);
        const QIcon icon = QIcon(QString::fromUtf8(":/images/qpwgraph.svg"));
        qpwgraph_options->setWindowIcon(icon);
        qpwgraph_options->setSizeGripEnabled(true);
        qpwgraph_options->setMaximumSize(QSize(480, 240));
        vboxLayout = new QVBoxLayout(qpwgraph_options);
        vboxLayout->setSpacing(4);
        vboxLayout->setContentsMargins(8, 8, 8, 8);
        vboxLayout->setObjectName("vboxLayout");
        OptionsTabWidget = new QTabWidget(qpwgraph_options);
        OptionsTabWidget->setObjectName("OptionsTabWidget");
        GeneralTabPage = new QWidget();
        GeneralTabPage->setObjectName("GeneralTabPage");
        gridLayout = new QGridLayout(GeneralTabPage);
        gridLayout->setSpacing(4);
        gridLayout->setContentsMargins(8, 8, 8, 8);
        gridLayout->setObjectName("gridLayout");
        SystemTrayEnabledCheckBox = new QCheckBox(GeneralTabPage);
        SystemTrayEnabledCheckBox->setObjectName("SystemTrayEnabledCheckBox");
        QFont font;
        font.setBold(false);
        SystemTrayEnabledCheckBox->setFont(font);

        gridLayout->addWidget(SystemTrayEnabledCheckBox, 0, 0, 1, 2);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 1, 0, 3, 1);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem1, 1, 2, 3, 1);

        SystemTrayQueryCloseCheckBox = new QCheckBox(GeneralTabPage);
        SystemTrayQueryCloseCheckBox->setObjectName("SystemTrayQueryCloseCheckBox");
        SystemTrayQueryCloseCheckBox->setFont(font);

        gridLayout->addWidget(SystemTrayQueryCloseCheckBox, 1, 1, 1, 1);

        SystemTrayStartMinimizedCheckBox = new QCheckBox(GeneralTabPage);
        SystemTrayStartMinimizedCheckBox->setObjectName("SystemTrayStartMinimizedCheckBox");
        SystemTrayStartMinimizedCheckBox->setFont(font);

        gridLayout->addWidget(SystemTrayStartMinimizedCheckBox, 2, 1, 1, 1);

        spacerItem2 = new QSpacerItem(20, 8, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem2, 3, 0, 1, 3);

        PatchbayQueryQuitCheckBox = new QCheckBox(GeneralTabPage);
        PatchbayQueryQuitCheckBox->setObjectName("PatchbayQueryQuitCheckBox");
        PatchbayQueryQuitCheckBox->setFont(font);

        gridLayout->addWidget(PatchbayQueryQuitCheckBox, 4, 0, 1, 3);

        spacerItem3 = new QSpacerItem(20, 8, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem3, 5, 0, 1, 3);

        spacerItem4 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem4, 6, 0, 1, 3);

        AlsaMidiEnabledCheckBox = new QCheckBox(GeneralTabPage);
        AlsaMidiEnabledCheckBox->setObjectName("AlsaMidiEnabledCheckBox");
        AlsaMidiEnabledCheckBox->setFont(font);

        gridLayout->addWidget(AlsaMidiEnabledCheckBox, 7, 0, 1, 3);

        OptionsTabWidget->addTab(GeneralTabPage, QString());
        FilterNodesTabPage = new QWidget();
        FilterNodesTabPage->setObjectName("FilterNodesTabPage");
        gridLayout1 = new QGridLayout(FilterNodesTabPage);
        gridLayout1->setSpacing(4);
        gridLayout1->setContentsMargins(8, 8, 8, 8);
        gridLayout1->setObjectName("gridLayout1");
        FilterNodesEnabledCheckBox = new QCheckBox(FilterNodesTabPage);
        FilterNodesEnabledCheckBox->setObjectName("FilterNodesEnabledCheckBox");
        FilterNodesEnabledCheckBox->setFont(font);

        gridLayout1->addWidget(FilterNodesEnabledCheckBox, 0, 0, 1, 2);

        FilterNodesNameComboBox = new QComboBox(FilterNodesTabPage);
        FilterNodesNameComboBox->setObjectName("FilterNodesNameComboBox");
        FilterNodesNameComboBox->setFont(font);
        FilterNodesNameComboBox->setEditable(true);

        gridLayout1->addWidget(FilterNodesNameComboBox, 1, 0, 1, 1);

        FilterNodesAddToolButton = new QToolButton(FilterNodesTabPage);
        FilterNodesAddToolButton->setObjectName("FilterNodesAddToolButton");
        FilterNodesAddToolButton->setMinimumSize(QSize(72, 24));
        FilterNodesAddToolButton->setFont(font);
        FilterNodesAddToolButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        gridLayout1->addWidget(FilterNodesAddToolButton, 1, 1, 1, 1);

        FilterNodesListWidget = new QListWidget(FilterNodesTabPage);
        FilterNodesListWidget->setObjectName("FilterNodesListWidget");
        FilterNodesListWidget->setMinimumSize(QSize(320, 80));
        FilterNodesListWidget->setFont(font);
        FilterNodesListWidget->setSelectionBehavior(QAbstractItemView::SelectRows);
        FilterNodesListWidget->setUniformItemSizes(true);

        gridLayout1->addWidget(FilterNodesListWidget, 2, 0, 3, 1);

        FilterNodesRemoveToolButton = new QToolButton(FilterNodesTabPage);
        FilterNodesRemoveToolButton->setObjectName("FilterNodesRemoveToolButton");
        FilterNodesRemoveToolButton->setMinimumSize(QSize(72, 24));
        FilterNodesRemoveToolButton->setFont(font);
        FilterNodesRemoveToolButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        gridLayout1->addWidget(FilterNodesRemoveToolButton, 2, 1, 1, 1);

        spacerItem5 = new QSpacerItem(20, 8, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout1->addItem(spacerItem5, 3, 1, 1, 1);

        FilterNodesClearToolButton = new QToolButton(FilterNodesTabPage);
        FilterNodesClearToolButton->setObjectName("FilterNodesClearToolButton");
        FilterNodesClearToolButton->setMinimumSize(QSize(72, 24));
        FilterNodesClearToolButton->setFont(font);
        FilterNodesClearToolButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        gridLayout1->addWidget(FilterNodesClearToolButton, 4, 1, 1, 1);

        spacerItem6 = new QSpacerItem(20, 8, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout1->addItem(spacerItem6, 5, 0, 1, 2);

        OptionsTabWidget->addTab(FilterNodesTabPage, QString());
        MergerNodesTabPage = new QWidget();
        MergerNodesTabPage->setObjectName("MergerNodesTabPage");
        gridLayout2 = new QGridLayout(MergerNodesTabPage);
        gridLayout2->setSpacing(4);
        gridLayout2->setContentsMargins(8, 8, 8, 8);
        gridLayout2->setObjectName("gridLayout2");
        MergerNodesEnabledCheckBox = new QCheckBox(MergerNodesTabPage);
        MergerNodesEnabledCheckBox->setObjectName("MergerNodesEnabledCheckBox");
        MergerNodesEnabledCheckBox->setFont(font);

        gridLayout2->addWidget(MergerNodesEnabledCheckBox, 0, 0, 1, 2);

        MergerNodesNameComboBox = new QComboBox(MergerNodesTabPage);
        MergerNodesNameComboBox->setObjectName("MergerNodesNameComboBox");
        MergerNodesNameComboBox->setFont(font);
        MergerNodesNameComboBox->setEditable(true);

        gridLayout2->addWidget(MergerNodesNameComboBox, 1, 0, 1, 1);

        MergerNodesAddToolButton = new QToolButton(MergerNodesTabPage);
        MergerNodesAddToolButton->setObjectName("MergerNodesAddToolButton");
        MergerNodesAddToolButton->setMinimumSize(QSize(72, 24));
        MergerNodesAddToolButton->setFont(font);
        MergerNodesAddToolButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        gridLayout2->addWidget(MergerNodesAddToolButton, 1, 1, 1, 1);

        MergerNodesListWidget = new QListWidget(MergerNodesTabPage);
        MergerNodesListWidget->setObjectName("MergerNodesListWidget");
        MergerNodesListWidget->setMinimumSize(QSize(320, 80));
        MergerNodesListWidget->setFont(font);
        MergerNodesListWidget->setSelectionBehavior(QAbstractItemView::SelectRows);
        MergerNodesListWidget->setUniformItemSizes(true);

        gridLayout2->addWidget(MergerNodesListWidget, 2, 0, 3, 1);

        MergerNodesRemoveToolButton = new QToolButton(MergerNodesTabPage);
        MergerNodesRemoveToolButton->setObjectName("MergerNodesRemoveToolButton");
        MergerNodesRemoveToolButton->setMinimumSize(QSize(72, 24));
        MergerNodesRemoveToolButton->setFont(font);
        MergerNodesRemoveToolButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        gridLayout2->addWidget(MergerNodesRemoveToolButton, 2, 1, 1, 1);

        spacerItem7 = new QSpacerItem(20, 8, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout2->addItem(spacerItem7, 3, 1, 1, 1);

        MergerNodesClearToolButton = new QToolButton(MergerNodesTabPage);
        MergerNodesClearToolButton->setObjectName("MergerNodesClearToolButton");
        MergerNodesClearToolButton->setMinimumSize(QSize(72, 24));
        MergerNodesClearToolButton->setFont(font);
        MergerNodesClearToolButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        gridLayout2->addWidget(MergerNodesClearToolButton, 4, 1, 1, 1);

        spacerItem8 = new QSpacerItem(20, 8, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout2->addItem(spacerItem8, 5, 0, 1, 2);

        OptionsTabWidget->addTab(MergerNodesTabPage, QString());

        vboxLayout->addWidget(OptionsTabWidget);

        DialogButtonBox = new QDialogButtonBox(qpwgraph_options);
        DialogButtonBox->setObjectName("DialogButtonBox");
        DialogButtonBox->setOrientation(Qt::Horizontal);
        DialogButtonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        vboxLayout->addWidget(DialogButtonBox);

        QWidget::setTabOrder(OptionsTabWidget, SystemTrayEnabledCheckBox);
        QWidget::setTabOrder(SystemTrayEnabledCheckBox, SystemTrayQueryCloseCheckBox);
        QWidget::setTabOrder(SystemTrayQueryCloseCheckBox, SystemTrayStartMinimizedCheckBox);
        QWidget::setTabOrder(SystemTrayStartMinimizedCheckBox, PatchbayQueryQuitCheckBox);
        QWidget::setTabOrder(PatchbayQueryQuitCheckBox, AlsaMidiEnabledCheckBox);
        QWidget::setTabOrder(AlsaMidiEnabledCheckBox, FilterNodesEnabledCheckBox);
        QWidget::setTabOrder(FilterNodesEnabledCheckBox, FilterNodesNameComboBox);
        QWidget::setTabOrder(FilterNodesNameComboBox, FilterNodesAddToolButton);
        QWidget::setTabOrder(FilterNodesAddToolButton, FilterNodesListWidget);
        QWidget::setTabOrder(FilterNodesListWidget, FilterNodesRemoveToolButton);
        QWidget::setTabOrder(FilterNodesRemoveToolButton, FilterNodesClearToolButton);
        QWidget::setTabOrder(FilterNodesClearToolButton, MergerNodesEnabledCheckBox);
        QWidget::setTabOrder(MergerNodesEnabledCheckBox, MergerNodesNameComboBox);
        QWidget::setTabOrder(MergerNodesNameComboBox, MergerNodesAddToolButton);
        QWidget::setTabOrder(MergerNodesAddToolButton, MergerNodesListWidget);
        QWidget::setTabOrder(MergerNodesListWidget, MergerNodesRemoveToolButton);
        QWidget::setTabOrder(MergerNodesRemoveToolButton, MergerNodesClearToolButton);
        QWidget::setTabOrder(MergerNodesClearToolButton, DialogButtonBox);

        retranslateUi(qpwgraph_options);

        OptionsTabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(qpwgraph_options);
    } // setupUi

    void retranslateUi(QDialog *qpwgraph_options)
    {
        qpwgraph_options->setWindowTitle(QCoreApplication::translate("qpwgraph_options", "Options", nullptr));
#if QT_CONFIG(tooltip)
        SystemTrayEnabledCheckBox->setToolTip(QCoreApplication::translate("qpwgraph_options", "Whether to enable the system tray icon", nullptr));
#endif // QT_CONFIG(tooltip)
        SystemTrayEnabledCheckBox->setText(QCoreApplication::translate("qpwgraph_options", "&Enable system tray icon", nullptr));
#if QT_CONFIG(tooltip)
        SystemTrayQueryCloseCheckBox->setToolTip(QCoreApplication::translate("qpwgraph_options", "Whether to show system tray message on main window close", nullptr));
#endif // QT_CONFIG(tooltip)
        SystemTrayQueryCloseCheckBox->setText(QCoreApplication::translate("qpwgraph_options", "Show &system tray message on close", nullptr));
#if QT_CONFIG(tooltip)
        SystemTrayStartMinimizedCheckBox->setToolTip(QCoreApplication::translate("qpwgraph_options", "Whether to start minimized to system tray", nullptr));
#endif // QT_CONFIG(tooltip)
        SystemTrayStartMinimizedCheckBox->setText(QCoreApplication::translate("qpwgraph_options", "Start &minimized to system tray", nullptr));
#if QT_CONFIG(tooltip)
        PatchbayQueryQuitCheckBox->setToolTip(QCoreApplication::translate("qpwgraph_options", "Whether to show activated patchbay message on application quit", nullptr));
#endif // QT_CONFIG(tooltip)
        PatchbayQueryQuitCheckBox->setText(QCoreApplication::translate("qpwgraph_options", "Show activated &patchbay message on quit", nullptr));
#if QT_CONFIG(tooltip)
        AlsaMidiEnabledCheckBox->setToolTip(QCoreApplication::translate("qpwgraph_options", "Whether to enable ALSA MIDI support", nullptr));
#endif // QT_CONFIG(tooltip)
        AlsaMidiEnabledCheckBox->setText(QCoreApplication::translate("qpwgraph_options", "Enable &ALSA MIDI support", nullptr));
        OptionsTabWidget->setTabText(OptionsTabWidget->indexOf(GeneralTabPage), QCoreApplication::translate("qpwgraph_options", "General", nullptr));
#if QT_CONFIG(tooltip)
        FilterNodesEnabledCheckBox->setToolTip(QCoreApplication::translate("qpwgraph_options", "Whether to filter / hide nodes from the graph", nullptr));
#endif // QT_CONFIG(tooltip)
        FilterNodesEnabledCheckBox->setText(QCoreApplication::translate("qpwgraph_options", "Enable filter / hide nodes", nullptr));
#if QT_CONFIG(tooltip)
        FilterNodesNameComboBox->setToolTip(QCoreApplication::translate("qpwgraph_options", "Node name (regex)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        FilterNodesAddToolButton->setToolTip(QCoreApplication::translate("qpwgraph_options", "Add node name (regex) to filter / hide list", nullptr));
#endif // QT_CONFIG(tooltip)
        FilterNodesAddToolButton->setText(QCoreApplication::translate("qpwgraph_options", "&Add", nullptr));
#if QT_CONFIG(tooltip)
        FilterNodesListWidget->setToolTip(QCoreApplication::translate("qpwgraph_options", "Node name (regex) filter / hide list", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        FilterNodesRemoveToolButton->setToolTip(QCoreApplication::translate("qpwgraph_options", "Remove node name (regex) from filter / hide list", nullptr));
#endif // QT_CONFIG(tooltip)
        FilterNodesRemoveToolButton->setText(QCoreApplication::translate("qpwgraph_options", "&Remove", nullptr));
#if QT_CONFIG(tooltip)
        FilterNodesClearToolButton->setToolTip(QCoreApplication::translate("qpwgraph_options", "Clear filter / hide list", nullptr));
#endif // QT_CONFIG(tooltip)
        FilterNodesClearToolButton->setText(QCoreApplication::translate("qpwgraph_options", "&Clear", nullptr));
        OptionsTabWidget->setTabText(OptionsTabWidget->indexOf(FilterNodesTabPage), QCoreApplication::translate("qpwgraph_options", "Filter", nullptr));
#if QT_CONFIG(tooltip)
        MergerNodesEnabledCheckBox->setToolTip(QCoreApplication::translate("qpwgraph_options", "Whether to merge / unify nodes on the patchbay", nullptr));
#endif // QT_CONFIG(tooltip)
        MergerNodesEnabledCheckBox->setText(QCoreApplication::translate("qpwgraph_options", "Enable merge / unify nodes", nullptr));
#if QT_CONFIG(tooltip)
        MergerNodesNameComboBox->setToolTip(QCoreApplication::translate("qpwgraph_options", "Node name (regex)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        MergerNodesAddToolButton->setToolTip(QCoreApplication::translate("qpwgraph_options", "Add node name (regex) to merger / unify list", nullptr));
#endif // QT_CONFIG(tooltip)
        MergerNodesAddToolButton->setText(QCoreApplication::translate("qpwgraph_options", "&Add", nullptr));
#if QT_CONFIG(tooltip)
        MergerNodesListWidget->setToolTip(QCoreApplication::translate("qpwgraph_options", "Node name (regex) merger / unify list", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        MergerNodesRemoveToolButton->setToolTip(QCoreApplication::translate("qpwgraph_options", "Remove node name (regex) from merger / unify list", nullptr));
#endif // QT_CONFIG(tooltip)
        MergerNodesRemoveToolButton->setText(QCoreApplication::translate("qpwgraph_options", "&Remove", nullptr));
#if QT_CONFIG(tooltip)
        MergerNodesClearToolButton->setToolTip(QCoreApplication::translate("qpwgraph_options", "Clear merger / unify list", nullptr));
#endif // QT_CONFIG(tooltip)
        MergerNodesClearToolButton->setText(QCoreApplication::translate("qpwgraph_options", "&Clear", nullptr));
        OptionsTabWidget->setTabText(OptionsTabWidget->indexOf(MergerNodesTabPage), QCoreApplication::translate("qpwgraph_options", "Merger", nullptr));
    } // retranslateUi

};

namespace Ui {
    class qpwgraph_options: public Ui_qpwgraph_options {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QPWGRAPH_OPTIONS_H
