/****************************************************************************
** Meta object code from reading C++ file 'qpwgraph_canvas.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../qpwgraph-v1.0.3/src/qpwgraph_canvas.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qpwgraph_canvas.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15qpwgraph_canvasE_t {};
} // unnamed namespace

template <> constexpr inline auto qpwgraph_canvas::qt_create_metaobjectdata<qt_meta_tag_ZN15qpwgraph_canvasE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qpwgraph_canvas",
        "added",
        "",
        "qpwgraph_node*",
        "node",
        "updated",
        "removed",
        "connected",
        "qpwgraph_port*",
        "port1",
        "port2",
        "disconnected",
        "qpwgraph_connect*",
        "connect",
        "changed",
        "renamed",
        "qpwgraph_item*",
        "item",
        "name",
        "connectItems",
        "disconnectItems",
        "selectAll",
        "selectNone",
        "selectInvert",
        "searchItem",
        "renameItem",
        "arrangeNodes",
        "zoomIn",
        "zoomOut",
        "zoomFit",
        "zoomReset",
        "updateNodes",
        "updateConnects",
        "renameTextChanged",
        "renameEditingFinished",
        "searchTextChanged",
        "searchEditingFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'added'
        QtMocHelpers::SignalData<void(qpwgraph_node *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'updated'
        QtMocHelpers::SignalData<void(qpwgraph_node *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'removed'
        QtMocHelpers::SignalData<void(qpwgraph_node *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'connected'
        QtMocHelpers::SignalData<void(qpwgraph_port *, qpwgraph_port *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 8, 10 },
        }}),
        // Signal 'disconnected'
        QtMocHelpers::SignalData<void(qpwgraph_port *, qpwgraph_port *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 8, 10 },
        }}),
        // Signal 'connected'
        QtMocHelpers::SignalData<void(qpwgraph_connect *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'renamed'
        QtMocHelpers::SignalData<void(qpwgraph_item *, const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'connectItems'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'disconnectItems'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectAll'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectNone'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectInvert'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'searchItem'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'renameItem'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'arrangeNodes'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomFit'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomReset'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateNodes'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateConnects'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'renameTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(33, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'renameEditingFinished'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'searchTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(35, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'searchEditingFinished'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<qpwgraph_canvas, qt_meta_tag_ZN15qpwgraph_canvasE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qpwgraph_canvas::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15qpwgraph_canvasE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15qpwgraph_canvasE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15qpwgraph_canvasE_t>.metaTypes,
    nullptr
} };

void qpwgraph_canvas::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<qpwgraph_canvas *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->added((*reinterpret_cast<std::add_pointer_t<qpwgraph_node*>>(_a[1]))); break;
        case 1: _t->updated((*reinterpret_cast<std::add_pointer_t<qpwgraph_node*>>(_a[1]))); break;
        case 2: _t->removed((*reinterpret_cast<std::add_pointer_t<qpwgraph_node*>>(_a[1]))); break;
        case 3: _t->connected((*reinterpret_cast<std::add_pointer_t<qpwgraph_port*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qpwgraph_port*>>(_a[2]))); break;
        case 4: _t->disconnected((*reinterpret_cast<std::add_pointer_t<qpwgraph_port*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qpwgraph_port*>>(_a[2]))); break;
        case 5: _t->connected((*reinterpret_cast<std::add_pointer_t<qpwgraph_connect*>>(_a[1]))); break;
        case 6: _t->changed(); break;
        case 7: _t->renamed((*reinterpret_cast<std::add_pointer_t<qpwgraph_item*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->connectItems(); break;
        case 9: _t->disconnectItems(); break;
        case 10: _t->selectAll(); break;
        case 11: _t->selectNone(); break;
        case 12: _t->selectInvert(); break;
        case 13: _t->searchItem(); break;
        case 14: _t->renameItem(); break;
        case 15: _t->arrangeNodes(); break;
        case 16: _t->zoomIn(); break;
        case 17: _t->zoomOut(); break;
        case 18: _t->zoomFit(); break;
        case 19: _t->zoomReset(); break;
        case 20: _t->updateNodes(); break;
        case 21: _t->updateConnects(); break;
        case 22: _t->renameTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->renameEditingFinished(); break;
        case 24: _t->searchTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->searchEditingFinished(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (qpwgraph_canvas::*)(qpwgraph_node * )>(_a, &qpwgraph_canvas::added, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (qpwgraph_canvas::*)(qpwgraph_node * )>(_a, &qpwgraph_canvas::updated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (qpwgraph_canvas::*)(qpwgraph_node * )>(_a, &qpwgraph_canvas::removed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (qpwgraph_canvas::*)(qpwgraph_port * , qpwgraph_port * )>(_a, &qpwgraph_canvas::connected, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (qpwgraph_canvas::*)(qpwgraph_port * , qpwgraph_port * )>(_a, &qpwgraph_canvas::disconnected, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (qpwgraph_canvas::*)(qpwgraph_connect * )>(_a, &qpwgraph_canvas::connected, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (qpwgraph_canvas::*)()>(_a, &qpwgraph_canvas::changed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (qpwgraph_canvas::*)(qpwgraph_item * , const QString & )>(_a, &qpwgraph_canvas::renamed, 7))
            return;
    }
}

const QMetaObject *qpwgraph_canvas::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qpwgraph_canvas::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15qpwgraph_canvasE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int qpwgraph_canvas::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void qpwgraph_canvas::added(qpwgraph_node * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void qpwgraph_canvas::updated(qpwgraph_node * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void qpwgraph_canvas::removed(qpwgraph_node * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void qpwgraph_canvas::connected(qpwgraph_port * _t1, qpwgraph_port * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void qpwgraph_canvas::disconnected(qpwgraph_port * _t1, qpwgraph_port * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void qpwgraph_canvas::connected(qpwgraph_connect * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void qpwgraph_canvas::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void qpwgraph_canvas::renamed(qpwgraph_item * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}
QT_WARNING_POP
